# El-Yurt Umidi Foundation Bot

This bot has been created independently for the El-Yurt Umidi Foundation for easily searching Universities' global rankings based on three top sources such as QS World University Rank, Times Higher Education Rank, and US News & World Report Rank.

## Installation

```bash
pip install elyuf